Todo list
*********

* clean up rpc interface
* use wsgi middleware
* add example with ceda oauth
* add front page ... 
* maybe add statistics
* add demo including docker
* use twitcher with c4i wps processes
* maybe beaker_mongodb: https://pypi.python.org/pypi/beaker_mongodb
* maybe use macaroons
